@@ -26,8 +26,8 @@ G_BEGIN_DECLS
 #define XFCE_TYPE_DISPLAY_SETTINGS_WAYLAND (xfce_display_settings_wayland_get_type ())
 G_DECLARE_FINAL_TYPE (XfceDisplaySettingsWayland, xfce_display_settings_wayland, XFCE, DISPLAY_SETTINGS_WAYLAND, XfceDisplaySettings)
 
-XfceDisplaySettings *xfce_display_settings_wayland_new (gboolean opt_minimal,
-                                                        GError **error);
+XfceDisplaySettings *
+xfce_display_settings_wayland_new (GError **error);
 
 G_END_DECLS
 
