@@ -471,11 +471,7 @@ xfce_keyboard_settings_constructed (GObject *object)
   xkl_config_rec_get_from_server (settings->priv->xkl_rec_config, settings->priv->xkl_engine);
 
   settings->priv->xkl_registry = xkl_config_registry_get_instance (settings->priv->xkl_engine);
-#ifdef HAVE_LIBXKLAVIER4
   xkl_config_registry_load (settings->priv->xkl_registry, FALSE);
-#else
-  xkl_config_registry_load (settings->priv->xkl_registry);
-#endif
 
   /* Tab */
   xkb_tab_layout_vbox = gtk_builder_get_object (GTK_BUILDER (settings), "xkb_tab_layout_vbox");
@@ -550,11 +546,7 @@ xfce_keyboard_settings_finalize (GObject *object)
 
 #ifdef HAVE_LIBXKLAVIER
   /* Stop xklavier engine */
-#ifdef HAVE_LIBXKLAVIER5
   xkl_engine_stop_listen (settings->priv->xkl_engine, XKLL_TRACK_KEYBOARD_STATE);
-#else
-  xkl_engine_stop_listen (settings->priv->xkl_engine);
-#endif /* HAVE_LIBXKLAVIER5 */
 
   g_object_unref (settings->priv->xkl_rec_config);
   g_object_unref (settings->priv->xkl_registry);
